/**
 * RdD system
 * Author: LeRatierBretonnien
 * Software License: GNU GPLv3
 */

/* -------------------------------------------- */
const RDD = {}
RDD.level_category = { 
  "generale": "-4", 
  "particuliere": "-8", 
  "speciale": "-11", 
  "connaissance": "-11", 
  "draconic": "-11", 
  "melee": "-6", 
  "tir": "-8", 
  "lancer": "-8"
}

/* -------------------------------------------- */
// Import Modules
import { RdDActor } from "./actor.js";
import { RdDItemSheet } from "./item-sheet.js";
import { RdDActorSheet } from "./actor-sheet.js";
import { RdDUtility } from "./rdd-utility.js";

/* -------------------------------------------- */
// Handlers management
const preloadHandlebarsTemplates = async function () {
	const templatePaths = [
		//Character Sheets
		'systems/foundryvtt-reve-de-dragon/templates/actor-sheet.html',
    //Items
		'systems/foundryvtt-reve-de-dragon/templates/item-competence-sheet.html',
		'systems/foundryvtt-reve-de-dragon/templates/competence-categorie.html',
    'systems/foundryvtt-reve-de-dragon/templates/competence-carac-defaut.html',
    'systems/foundryvtt-reve-de-dragon/templates/competence-base.html',
    // Dialogs
    'systems/foundryvtt-reve-de-dragon/templates/dialog-competence.html'
	];

	return loadTemplates(templatePaths);
}

/* -------------------------------------------- */
/*  Foundry VTT Initialization                  */
/* -------------------------------------------- */

Hooks.once("init", async function() {
  console.log(`Initializing Reve de Dragon System`);
  // preload handlebars templates
  preloadHandlebarsTemplates();
  
	/**
	 * Set an initiative formula for the system
	 * @type {String}
	 */
	CONFIG.Combat.initiative = {
	  formula: "1d20",
    decimals: 2
  };

	// Define custom Entity classes
  CONFIG.Actor.entityClass = RdDActor;
  CONFIG.RDD = RDD;
  
  // Register sheet application classes
  Actors.unregisterSheet("core", ActorSheet);
  Actors.registerSheet("foundryvtt-reve-de-dragon", RdDActorSheet, { makeDefault: true });
  Items.unregisterSheet("core", ItemSheet);
  Items.registerSheet("foundryvtt-reve-de-dragon", RdDItemSheet, {makeDefault: true});

});
